@@ -126,6 +126,8 @@ ALCDTTM <- function(ALCDTTM) {
 #' 
 #' @param DHH_SEX sex of respondent (1 - male, 2 - female)
 #' 
+#' @param ALW_1 Drinks in the last week (1 - yes, 2 - no)
+#' 
 #' @param ALW_2A1 Number of drinks on Sunday
 #' 
 #' @param ALW_2A2 Number of drinks on Monday
@@ -147,7 +149,8 @@ ALCDTTM <- function(ALCDTTM) {
 #'   \item 2 - non-binge drinker
 #'  }
 #' 
-#' @examples 
+#' @examples
+#'  
 #' # Using binge_drinker_fun() to create binge_drinker values across CCHS cycles
 #' # binge_drinker_fun() is specified in variable_details.csv along with the
 #' # CCHS variables and cycles included.
@@ -160,8 +163,8 @@ ALCDTTM <- function(ALCDTTM) {
 #' library(cchsflow)
 #' binge2001 <- rec_with_table(
 #'   cchs2001_p, c(
-#'     "DHH_SEX", "ALW_2A1", "ALW_2A2", "ALW_2A3", "ALW_2A4", "ALW_2A5",
-#'     "ALW_2A6", "ALW_2A7", "binge_drinker"
+#'     "ALW_1", "DHH_SEX", "ALW_2A1", "ALW_2A2", "ALW_2A3", "ALW_2A4",
+#'     "ALW_2A5", "ALW_2A6", "ALW_2A7", "binge_drinker"
 #'   )
 #' )
 #' 
@@ -169,8 +172,8 @@ ALCDTTM <- function(ALCDTTM) {
 #' 
 #' binge2009_2010 <- rec_with_table(
 #'   cchs2009_2010_p, c(
-#'     "DHH_SEX", "ALW_2A1", "ALW_2A2", "ALW_2A3", "ALW_2A4", "ALW_2A5",
-#'     "ALW_2A6", "ALW_2A7", "binge_drinker"
+#'     "ALW_1", "DHH_SEX", "ALW_2A1", "ALW_2A2", "ALW_2A3", "ALW_2A4",
+#'     "ALW_2A5", "ALW_2A6", "ALW_2A7", "binge_drinker"
 #'   )
 #' )
 #' 
@@ -185,12 +188,13 @@ ALCDTTM <- function(ALCDTTM) {
 #' # Using binge_drinker_fun() to generate binge_drinker with user-inputted
 #' # values.
 #' #
-#' # Let's say you are a male, and you had 3 drinks on Sunday, 1 drink on
+#' # Let's say you are a male, and you had drinks in the last week. Let's say
+#' # you had 3 drinks on Sunday, 1 drink on
 #' # Monday, 6 drinks on Tuesday, 0 drinks on Wednesday, 3 drinks on Thurday,
 #' # 8 drinks on Friday, and 2 drinks on Saturday. Using binge_drinker_fun(),
 #' # we can check if you would be classified as a drinker.
 #' 
-#' binge <- binge_drinker_fun(DHH_SEX = 1, ALW_2A1 = 3, ALW_2A2 = 1,
+#' binge <- binge_drinker_fun(DHH_SEX = 1, ALW_1 = 1, ALW_2A1 = 3, ALW_2A2 = 1,
 #'                           ALW_2A3 = 6, ALW_2A4 = 0, ALW_2A5 = 3,
 #'                           ALW_2A6 = 8, ALW_2A7 = 2)
 #' 
@@ -198,24 +202,28 @@ ALCDTTM <- function(ALCDTTM) {
 #' @export
 
 binge_drinker_fun <-
-  function(DHH_SEX, ALW_2A1, ALW_2A2, ALW_2A3, ALW_2A4, ALW_2A5, ALW_2A6,
+  function(DHH_SEX, ALW_1, ALW_2A1, ALW_2A2, ALW_2A3, ALW_2A4, ALW_2A5, ALW_2A6,
            ALW_2A7) {
-    # Males with at least one day with 5 or more drinks
-    if_else2((DHH_SEX == 1 & (ALW_2A1 >= 5 | ALW_2A2 >= 5 | ALW_2A3 >=5 |
-                              ALW_2A4 >= 5 | ALW_2A5 >= 5 | ALW_2A6 >= 5 |
-                              ALW_2A7 >= 5)), 1,
-    # Males with no days with 5 or more drinks
-    if_else2((DHH_SEX == 1 & (ALW_2A1 %in% (0:4) & ALW_2A2 %in% (0:4) &
-                              ALW_2A3 %in% (0:4) & ALW_2A4 %in% (0:4) &
-                              ALW_2A5 %in% (0:4) & ALW_2A6 %in% (0:4) &
-                              ALW_2A7 %in% (0:4))), 2,
-    # Females with at least one day with 4 or more drinks
-    if_else2((DHH_SEX == 2 & (ALW_2A1 >= 4 | ALW_2A2 >= 4 | ALW_2A3 >= 4 |
-                               ALW_2A4 >= 4 | ALW_2A5 >= 4 | ALW_2A6 >= 4 |
-                               ALW_2A7 >= 4)), 1,
-    # Females with no days with 4 or more drinks
-    if_else2((DHH_SEX == 2 & (ALW_2A1 %in% (0:3) & ALW_2A2 %in% (0:3) &
-                               ALW_2A3 %in% (0:3) & ALW_2A4 %in% (0:3) &
-                               ALW_2A5 %in% (0:3) & ALW_2A6 %in% (0:3) &
-                               ALW_2A7 %in% (0:3))), 2, NA))))
+    # If respondents had alcohol in the last week
+    if_else2(ALW_1 == 1,
+      # Males with at least one day with 5 or more drinks
+      if_else2((DHH_SEX == 1 & (ALW_2A1 >= 5 | ALW_2A2 >= 5 | ALW_2A3 >=5 |
+                                ALW_2A4 >= 5 | ALW_2A5 >= 5 | ALW_2A6 >= 5 |
+                                ALW_2A7 >= 5)), 1,
+      # Males with no days with 5 or more drinks
+      if_else2((DHH_SEX == 1 & (ALW_2A1 %in% (0:4) & ALW_2A2 %in% (0:4) &
+                                ALW_2A3 %in% (0:4) & ALW_2A4 %in% (0:4) &
+                                ALW_2A5 %in% (0:4) & ALW_2A6 %in% (0:4) &
+                                ALW_2A7 %in% (0:4))), 2,
+      # Females with at least one day with 4 or more drinks
+      if_else2((DHH_SEX == 2 & (ALW_2A1 >= 4 | ALW_2A2 >= 4 | ALW_2A3 >= 4 |
+                                ALW_2A4 >= 4 | ALW_2A5 >= 4 | ALW_2A6 >= 4 |
+                                ALW_2A7 >= 4)), 1,
+      # Females with no days with 4 or more drinks
+      if_else2((DHH_SEX == 2 & (ALW_2A1 %in% (0:3) & ALW_2A2 %in% (0:3) &
+                                ALW_2A3 %in% (0:3) & ALW_2A4 %in% (0:3) &
+                                ALW_2A5 %in% (0:3) & ALW_2A6 %in% (0:3) &
+                                ALW_2A7 %in% (0:3))), 2, "NA(b)")))),
+      # Respondents who didn't indicate they had alcohol in the last week
+      "NA(a)")
   }
\ No newline at end of file
