@@ -1,43 +1,47 @@
 test_that("binge_drinker_fun has expected output when sex is out of range", {
-  expect_equal(binge_drinker_fun(-1, 1, 1, 1, 1, 1, 1, 1), NA)
+  expect_equal(binge_drinker_fun(-1, 1, 1, 1, 1, 1, 1, 1, 1), "NA(b)")
+})
+
+test_that("binge_drinker_fun has expected output when ALW_1 is out of range", {
+  expect_equal(binge_drinker_fun(1, -1, 1, 1, 1, 1, 1, 1, 1), "NA(a)")
 })
 
 test_that("binge_drinker_fun has expected output when ALW_2A1 is
           out of range", {
-  expect_equal(binge_drinker_fun(1, -1, 1, 1, 1, 1, 1, 1), NA)
+  expect_equal(binge_drinker_fun(1, 1, -1, 1, 1, 1, 1, 1, 1), "NA(b)")
 })
 
 test_that("binge_drinker_fun has expected output when ALW_2A2 is
           out of range", {
-  expect_equal(binge_drinker_fun(1, 1, -1, 1, 1, 1, 1, 1), NA)
+  expect_equal(binge_drinker_fun(1, 1, 1, -1, 1, 1, 1, 1, 1), "NA(b)")
 })
 
 test_that("binge_drinker_fun has expected output when ALW_2A3 is
           out of range", {
-  expect_equal(binge_drinker_fun(1, 1, 1, -1, 1, 1, 1, 1), NA)
+  expect_equal(binge_drinker_fun(1, 1, 1, 1, -1, 1, 1, 1, 1), "NA(b)")
 })
 
 test_that("binge_drinker_fun has expected output when ALW_2A4 is
           out of range", {
-  expect_equal(binge_drinker_fun(1, 1, 1, 1, -1, 1, 1, 1), NA)
+  expect_equal(binge_drinker_fun(1, 1, 1, 1, 1, -1, 1, 1, 1), "NA(b)")
 })
 
 test_that("binge_drinker_fun has expected output when ALW_2A5 is
           out of range", {
-  expect_equal(binge_drinker_fun(1, 1, 1, 1, 1, -1, 1, 1), NA)
+  expect_equal(binge_drinker_fun(1, 1, 1, 1, 1, 1, -1, 1, 1), "NA(b)")
 })
 
 test_that("binge_drinker_fun has expected output when ALW_2A6 is
           out of range", {
-  expect_equal(binge_drinker_fun(1, 1, 1, 1, 1, 1, -1, 1), NA)
+  expect_equal(binge_drinker_fun(1, 1, 1, 1, 1, 1, 1, -1, 1), "NA(b)")
 })
 
 test_that("binge_drinker_fun has expected output when ALW_2A7 is
           out of range", {
-  expect_equal(binge_drinker_fun(1, 1, 1, 1, 1, 1, 1, -1), NA)
+  expect_equal(binge_drinker_fun(1, 1, 1, 1, 1, 1, 1, 1, -1), "NA(b)")
 })
 
 test_that("binge_drinker_fun has expected output when all values are
           in range", {
-  expect_equal(binge_drinker_fun(1, 1, 1, 1, 1, 1, 1, 1), 2)
+  expect_equal(binge_drinker_fun(1, 1, 1, 1, 1, 1, 1, 1, 1), 2)
 })
\ No newline at end of file
